@@ -4,23 +4,23 @@ server <- function(){
 }
 
 tile_server <- function(){
-  "https://thredds.daac.ornl.gov/thredds/fileServer/ornldaac/1840/tiles"
+  "https://thredds.daac.ornl.gov/thredds/fileServer/ornldaac/2129/tiles"
 }
 
 ncss_server <- function(frequency, catalog = FALSE){
   url <- "https://thredds.daac.ornl.gov/thredds/ncss/ornldaac"
   
   if(catalog){
-    return(file.path(url, "/1840/catalog.html"))
+    return(file.path(url, "2129/catalog.html"))
   }
   
   # set final url path depending on the frequency of the
   # data requested
   if(frequency == "monthly"){
-    url <- sprintf("%s/%s", url, 1855)
+    url <- file.path(url, 2131)
   } else if (frequency == "annual"){
-    url <- sprintf("%s/%s", url, 1852)
+    url <- file.path(url, 2130)
   } else {
-    url <- sprintf("%s/%s", url, 1840)
+    url <- file.path(url, 2129)
   }
 }
\ No newline at end of file
